{
	"name":"Accounting only profile",
	"version":"1.0",
	"author":"Tiny",
	"category":"Profile",
	"depends":["account_tax_include", "account", "report_analytic_line" ],
	"demo_xml":[],
	"update_xml":[],
	"active":False,
	"installable":True,
}
